@@ -113,24 +113,34 @@ class Drone:
             else:
                 return False
 
-        self._serialport = serial.Serial(
-            port        = portname,
-            baudrate    = 57600)
+        try:
 
-        if( self.isOpen() ):
-            self._flagThreadRun = True
-            self._thread = Thread(target=self._receiving, args=(), daemon=True)
-            self._thread.start()
+            self._serialport = serial.Serial(
+                port        = portname,
+                baudrate    = 57600)
 
-            # 로그 출력
-            self._printLog("Connected.({0})".format(portname))
+            if( self.isOpen() ):
+                self._flagThreadRun = True
+                self._thread = Thread(target=self._receiving, args=(), daemon=True)
+                self._thread.start()
+
+                # 로그 출력
+                self._printLog("Connected.({0})".format(portname))
+
+                return True
+            else:
+                # 오류 메세지 출력
+                self._printError("Could not connect to E-DRONE.")
+
+                return False
+
+        except:
+                # 오류 메세지 출력
+                self._printError("Could not connect to E-DRONE.")
+
+                return False
 
-            return True
-        else:
-            # 오류 메세지 출력
-            self._printError("Could not connect to E-DRONE.")
 
-            return False
 
 
 
@@ -617,9 +627,9 @@ class Drone:
             return None
 
         timeSec     = timeMs / 1000
-        timeStart   = time.time()
+        timeStart   = time.perf_counter()
 
-        while ((time.time() - timeStart) < timeSec):
+        while ((time.perf_counter() - timeStart) < timeSec):
             self.sendControl(roll, pitch, yaw, throttle)
             sleep(0.02)
 
@@ -973,6 +983,24 @@ class Drone:
 
 
 
+    def sendClearTrim(self):
+        
+        header = Header()
+        
+        header.dataType = DataType.Command
+        header.length   = Command.getSize()
+        header.from_    = DeviceType.Tester
+        header.to_      = DeviceType.Drone
+
+        data = Command()
+
+        data.commandType    = CommandType.ClearTrim
+        data.option         = 0
+
+        return self.transfer(header, data)
+
+
+
     def sendSetDefault(self, deviceType):
         
         if  ( (not isinstance(deviceType, DeviceType)) ):
@@ -1241,6 +1269,41 @@ class Drone:
 
 
 
+    def sendLightDefaultColor(self, lightMode, interval, r, g, b):
+        
+        if  (((not isinstance(lightMode, LightModeDrone)) and (not isinstance(lightMode, LightModeController))) or
+            (not isinstance(interval, int)) or
+            (not isinstance(r, int)) or
+            (not isinstance(g, int)) or
+            (not isinstance(b, int))):
+            return None
+
+        header = Header()
+        
+        header.dataType = DataType.LightDefault
+        header.length   = LightModeColor.getSize()
+        header.from_    = DeviceType.Base
+
+        if      isinstance(lightMode, LightModeDrone):
+            header.to_  = DeviceType.Drone
+        elif    isinstance(lightMode, LightModeController):
+            header.to_  = DeviceType.Controller
+        else:
+            return None
+
+        data = LightModeColor()
+
+        data.mode.mode      = lightMode.value
+        data.mode.interval  = interval
+
+        data.color.r        = r
+        data.color.g        = g
+        data.color.b        = b
+
+        return self.transfer(header, data)
+
+
+
 # Light End
 
 
